# Matplotlib surface plotting

Matplotlib 3D mesh plotter with no additional dependencies (optional the nibabel for loading example brain imaging mesh).
![plot](https://github.com/kwagstyl/matplotlib_surface_plotting/blob/main/figs/demo_plot.png?raw=true)

pip install matplotlib-surface-plotting

Run example:

python scripts/script_matplotlib.py
to create demo_plot.png using demo files


Based on a matplotlib blogpost by Nicolas P. Rougier

Contributors: M. Ripart, U. Popple, K. Wagstyl 
